Examples
========

.. include:: examples/README.rst

.. toctree::
   :maxdepth: 1

   Build Wflow model <examples/build_model>
   Plot Wflow model maps and forcing <examples/base_plots>
   Export wflow staticmaps netcdf to raster files <examples/nc_to_gtiff>

